=====
dalia
=====


.. image:: https://img.shields.io/pypi/v/dalia.svg
        :target: https://pypi.python.org/pypi/dalia

.. image:: https://img.shields.io/travis/brews/dalia.svg
        :target: https://travis-ci.org/brews/dalia

.. image:: https://readthedocs.org/projects/dalia/badge/?version=latest
        :target: https://dalia.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Mythic goddess of fate. Giver and taker of goods and property.

This code is under heavy development. Don't use it.

* Documentation: https://dalia.readthedocs.io.
* Free software: Apache License 2.0

Features
--------

* Read CSVV files with ``dalia.read_csvv()``.
* Read regional hierarchy files as a tree with ``dalia.read_hierarchy()``.

Installation
------------

To install with ``pip``::

    pip install dalia

